/*******************************************************************************
* This software program is available to you under a choice of one of two 
* licenses. You may choose to be licensed under either the GNU General Public 
* License (GPL) Version 2, June 1991, available at 
* http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
* text of which follows:
* 
* Recipient has requested a license and Intel Corporation ("Intel") is willing
* to grant a license for the software entitled Linux Intel Advanced Network
* Services (iANS) (the "Licensed Program") being provided by Intel Corporation.
* The following definitions apply to this license:
* 
* "Licensed Patents" means patent claims licensable by Intel Corporation which 
* are necessarily infringed by the use of sale of the Software alone or when 
* combined with the operating system referred to below.
* 
* "Recipient" means the party to whom Intel delivers this Software.
* 
* "Licensee" means Recipient and those third parties that receive a license to 
* any operating system available under the GNU Public License version 2.0 or 
* later.
* 
* Copyright (c) 1999 - 2002 Intel Corporation.
* All rights reserved.
* 
* The license is provided to Recipient and Recipient's Licensees under the 
* following terms.
* 
* Redistribution and use in source and binary forms of the Software, with or 
* without modification, are permitted provided that the following conditions 
* are met:
* 
* Redistributions of source code of the Software may retain the above 
* copyright notice, this list of conditions and the following disclaimer.
* 
* Redistributions in binary form of the Software may reproduce the above 
* copyright notice, this list of conditions and the following disclaimer in 
* the documentation and/or materials provided with the distribution.
* 
* Neither the name of Intel Corporation nor the names of its contributors 
* shall be used to endorse or promote products derived from this Software 
* without specific prior written permission.
* 
* Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
* royalty-free patent license under Licensed Patents to make, use, sell, offer 
* to sell, import and otherwise transfer the Software, if any, in source code 
* and object code form. This license shall include changes to the Software 
* that are error corrections or other minor changes to the Software that do 
* not add functionality or features when the Software is incorporated in any 
* version of an operating system that has been distributed under the GNU 
* General Public License 2.0 or later. This patent license shall apply to the 
* combination of the Software and any operating system licensed under the GNU 
* Public License version 2.0 or later if, at the time Intel provides the 
* Software to Recipient, such addition of the Software to the then publicly 
* available versions of such operating systems available under the GNU Public 
* License version 2.0 or later (whether in gold, beta or alpha form) causes 
* such combination to be covered by the Licensed Patents. The patent license 
* shall not apply to any other combinations which include the Software. NO 
* hardware per se is licensed hereunder.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
* IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
* ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
* (INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
* ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/
 /***************************************************************************
 **                                                                        **
 ** INTEL CORPORATION                                                      **
 **                                                                        **
 ** This software is supplied under the terms of the license included      **
 ** above.  All use of this software must be in accordance with the terms  **
 ** of that license.                                                       **
 **                                                                        **
 **  THIS FILE IS INCLUDED BY ians_core.o. HENCE, IT SHOULD NOT BE         **
 **  MODIFIED!                                                             **
 **                                                                        **
 **  Module Name:                                                          **
 **   ians_base.h                                                          **
 **                                                                        **
 **  Abstract:                                                             **
 **    This module contains all the functions needed for the interface of  **
 **    the iANS module with the base driver.                               **
 **                                                                        **
 **  Environment:                                                          **
 **    Kernel Mode  (linux 2.2.x, 2.4.x)                                   **
 **                                                                        **
 ***************************************************************************/

#ifndef _IANS_BASE_H
#define _IANS_BASE_H

#include "base_comm.h"
#include "incg_types.h"
//#include "incg_net.h"
//#include "incg_utils.h"


//used for translating ans supported modes to
//base driver supported modes.
typedef enum _IANS_BD_MODE {
                IANS_BD_OFF,
                IANS_BD_ON
        } IANS_BD_MODE;


int baseOpenDevice(device_t *ansDev);
int baseCloseDevice(device_t  *ansDev);
int baseSend(device_t *ansDev, message_t *msg);
int baseDoIoctl(device_t *ansDev, preq_t ifr, int cmd);
int baseSetMacAddr(device_t *ansDev, sockAddr_t *addr);
MAC_ADDR baseGetMacAddr(device_t *ansDev);
pstats_t baseGetStats(device_t *ansDev);
int baseSetMulticastList(device_t *ansDev, MULTICAST_LIST *multicastList, PACKET_FILTER packetFilter);
int baseChangeMtu(device_t *ansDev, int new_mtu);

int baseIdentify (device_t *ansDev);
int baseSetExtMode (device_t *ansDev, BOOLEAN attributed_mode);
int baseGetExtendedCapability ( device_t *ansDev, IANS_BD_PARAM_EXT_CAP *cap);
int baseGetStatusInfo ( device_t *ansDev, IANS_BD_IOC_PARAM_STATUS *stat);
int baseGetEthToolStatusInfo ( device_t *ansDev, IANS_BD_IOC_PARAM_STATUS *stat);
int baseMIIReadRegister(device_t *ansDev, UINT16 phy_addr, UINT16 reg_addr, UINT16 *reg_data);
int baseMIIGetPhyAddress(device_t *ansDev, UINT16 *phy_addr);

#ifdef IANS_TAGGING
int baseSetTaggingMode (device_t *ansDev, IANS_BD_TAGGING_MODE TagMode);
int baseGetTaggingCapability (device_t *ansDev, IANS_BD_PARAM_ITAG_CAP *cap);
#endif

#ifdef IANS_BINDING_BASED_VLAN
int baseSetVlanMode (device_t *ansDev, BOOLEAN reqVlanSup, BOOLEAN reqFilterSup);
int baseSetVlanIdTable(device_t *ansDev, UINT16 *vlanIdTable, UINT32 vlanNum);
int baseGetVlanCapability (device_t *ansDev, IANS_BD_PARAM_IVLAN_CAP *cap);
#endif

int baseUndoSettings (device_t *ansDev);

int baseSetNotifyCB(device_t *ansDev);

#ifdef __ia64__
#pragma pack(8)
#else
#pragma pack(4)
#endif

//Used by iAnsNotify
typedef struct _IANS_INDICATION_HEADER
{
  int  IndType;

} IANS_INDICATION_HEADER, *PIANS_INDICATION_HEADER;


//Used by iAnsNotify to send indication up the flow
//using a generic ioctl.
typedef struct _IANS_BD_IND_PARAM_STATUS
{
        IANS_INDICATION_HEADER   Header;
        IANS_BD_PARAM_STATUS     Status;
} IANS_BD_IND_PARAM_STATUS, *PIANS_BD_IND_PARAM_STATUS;


#pragma pack()


extern inline UINT32 convertSpeedToMBPS(UINT32 speed) {
    
    UINT32 NumZeroes = iAnsLog2(speed);
    UINT32 MBPSSpeed = 1;
    UINT32 i;

    if (speed == 0)
                return 0;
    
    for (i=0; i<NumZeroes; i++)
       MBPSSpeed *= 10;

    return MBPSSpeed;
}


#endif //_IANS_BASE_H

