/*******************************************************************************
* This software program is available to you under a choice of one of two 
* licenses. You may choose to be licensed under either the GNU General Public 
* License (GPL) Version 2, June 1991, available at 
* http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
* text of which follows:
* 
* Recipient has requested a license and Intel Corporation ("Intel") is willing
* to grant a license for the software entitled Linux Intel Advanced Network
* Services (iANS) (the "Licensed Program") being provided by Intel Corporation.
* The following definitions apply to this license:
* 
* "Licensed Patents" means patent claims licensable by Intel Corporation which 
* are necessarily infringed by the use of sale of the Software alone or when 
* combined with the operating system referred to below.
* 
* "Recipient" means the party to whom Intel delivers this Software.
* 
* "Licensee" means Recipient and those third parties that receive a license to 
* any operating system available under the GNU Public License version 2.0 or 
* later.
* 
* Copyright (c) 1999 - 2002 Intel Corporation.
* All rights reserved.
* 
* The license is provided to Recipient and Recipient's Licensees under the 
* following terms.
* 
* Redistribution and use in source and binary forms of the Software, with or 
* without modification, are permitted provided that the following conditions 
* are met:
* 
* Redistributions of source code of the Software may retain the above 
* copyright notice, this list of conditions and the following disclaimer.
* 
* Redistributions in binary form of the Software may reproduce the above 
* copyright notice, this list of conditions and the following disclaimer in 
* the documentation and/or materials provided with the distribution.
* 
* Neither the name of Intel Corporation nor the names of its contributors 
* shall be used to endorse or promote products derived from this Software 
* without specific prior written permission.
* 
* Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
* royalty-free patent license under Licensed Patents to make, use, sell, offer 
* to sell, import and otherwise transfer the Software, if any, in source code 
* and object code form. This license shall include changes to the Software 
* that are error corrections or other minor changes to the Software that do 
* not add functionality or features when the Software is incorporated in any 
* version of an operating system that has been distributed under the GNU 
* General Public License 2.0 or later. This patent license shall apply to the 
* combination of the Software and any operating system licensed under the GNU 
* Public License version 2.0 or later if, at the time Intel provides the 
* Software to Recipient, such addition of the Software to the then publicly 
* available versions of such operating systems available under the GNU Public 
* License version 2.0 or later (whether in gold, beta or alpha form) causes 
* such combination to be covered by the Licensed Patents. The patent license 
* shall not apply to any other combinations which include the Software. NO 
* hardware per se is licensed hereunder.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
* IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
* ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
* (INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
* ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/
/***************************************************************************
**                                                                        **
** INTEL CORPORATION                                                      **
**                                                                        **
** This software is supplied under the terms of the license included      **
** above.  All use of this software must be in accordance with the terms  **
** of that license.                                                       **
**                                                                        **
**  Module Name:                                                          **
**    incg_flow.c                                                         **
**                                                                        **
**  Abstract:                                                             **
**    This module translates Kernel control / status to                   **
**    iANS control /status.                                               **
**                                                                        **
**  Environment:                                                          **
**    Kernel Mode (linux 2.2.x, 2.4.x)                                    **
**                                                                        **
***************************************************************************/

#include <linux/errno.h>

#include "incg_utils.h"
//#include "incg_flow.h"


/*--------------------------------------------------------------------*
 | iANSOSToFlowStatus()
 *--------------------------------------------------------------------*/

// noam. to check the function. are the input value are fit to linux ?
IANS_FLOW_STATUS iANSOSToFlowStatus(OS_STATUS OSStatus)
{
      IANS_FLOW_STATUS  FlowStatus;

      switch (OSStatus) {
            case OS_STATUS_OK:      FlowStatus = FLOW_OK;               break;
            case EBUSY:             FlowStatus = FLOW_BUSY;             break;
            case ENXIO:             FlowStatus = FLOW_DOESNT_EXIST;     break;
            case EEXIST:            FlowStatus = FLOW_ALREADY_EXIST;    break;
            case EOPNOTSUPP:        FlowStatus = FLOW_UNKNOWN_OPCODE;   break;
            case ENODEV:            FlowStatus = FLOW_WRONG_OBJECT;     break;
                  // ESTATE is defined to be =  EINVAL !
                  //	case ESTATE:		FlowStatus = FLOW_WRONG_STATE;		break;
            case EINVAL:            FlowStatus = FLOW_BAD_PARAMETER;    break;
            case ENOSPC:            FlowStatus = FLOW_DB_FULL;          break;
            case ENOBUFS:           FlowStatus = FLOW_COMM_RESOURCES;   break;
            case ENOMEM:            FlowStatus = FLOW_GP_RESOURCES;     break;
            case EPROTO:            FlowStatus = FLOW_PROTOCOL_ERR;     break;
            default:
#ifdef INCG_DEBUG
                  /* @@@ Should think of a better way @@@ */
                  FlowStatus = FLOW_INTERNAL_ERROR;
                  iAnsPanic ("Can't convert OSStatus=%d to Flow",
                             (int)OSStatus );
#else
                  FlowStatus = FLOW_INTERNAL_ERROR;
#endif

      } /* switch OSStatus */
      return( FlowStatus );
} /* iANSOSToFlowStatus() */


/*--------------------------------------------------------------------*
 | iANSFlowToOSStatus()
 *--------------------------------------------------------------------*/
OS_STATUS iANSFlowToOSStatus(IANS_FLOW_STATUS FlowStatus)
{
      OS_STATUS   OSStatus;

      switch (FlowStatus) {
            case FLOW_OK:                 OSStatus = OS_STATUS_OK;      break;
            case FLOW_BUSY:               OSStatus = EBUSY;             break;
            case FLOW_DOESNT_EXIST:       OSStatus = ENXIO;             break;
            case FLOW_ALREADY_EXIST:      OSStatus = EEXIST;            break;
            case FLOW_UNKNOWN_OPCODE:     OSStatus = EOPNOTSUPP;        break;
            case FLOW_WRONG_OBJECT:       OSStatus = ENODEV;            break;
            case FLOW_WRONG_STATE:        OSStatus = ESTATE;            break;
            case FLOW_BAD_PARAMETER:      OSStatus = EINVAL;            break;
            case FLOW_DB_FULL:            OSStatus = ENOSPC;            break;
            case FLOW_COMM_RESOURCES:     OSStatus = ENOBUFS;           break;
            case FLOW_GP_RESOURCES:       OSStatus = ENOMEM;            break;
            case FLOW_PROTOCOL_ERR:       OSStatus = EPROTO;            break;
            case FLOW_CONTINUE:
            case FLOW_TRANSFERED:
            case FLOW_MIN_ERROR:
            case FLOW_INTERNAL_ERROR:
            default:
#ifdef INCG_DEBUG
                  /* @@@ Should think of a better way @@@ */
                  OSStatus = ENXIO; /* need some non-zero value...*/
                  iAnsPanic ("Can't convert FlowStatus=%d to OS",
                             (int)FlowStatus );
#else
                  /* @@ add a log message ? */
                  OSStatus = ENXIO; /* need some non-zero value...*/
#endif

      } /* switch FlowStatus */
      return( OSStatus );
} /* iANSFlowToOSStatus() */

